@@ -53,8 +53,8 @@ XkbDDXFakePointerMotion(unsigned flags,int x,int y)
 int 		   oldX,oldY;
 ScreenPtr	   pScreen, oldScreen;
 
-    GetSpritePosition(&oldX, &oldY);
-    pScreen = oldScreen = GetSpriteWindow()->drawable.pScreen;
+    GetSpritePosition(inputInfo.pointer, &oldX, &oldY);
+    pScreen = oldScreen = GetSpriteWindow(inputInfo.pointer)->drawable.pScreen;
 
 #ifdef PANORAMIX
     if (!noPanoramiXExtension) {
@@ -113,7 +113,7 @@ ScreenPtr	   pScreen, oldScreen;
     }
 
     if (pScreen != oldScreen)
-	NewCurrentScreen(pScreen, oldX, oldY);
+	NewCurrentScreen(inputInfo.pointer, pScreen, oldX, oldY);
     if (pScreen->SetCursorPosition)
-	(*pScreen->SetCursorPosition)(pScreen, oldX, oldY, TRUE);
+	(*pScreen->SetCursorPosition)(inputInfo.pointer, pScreen, oldX, oldY, TRUE);
 }
